@@ -23,7 +23,7 @@ Module contains objects that wrap mlt.Transition objects used to mix video betwe
 two tracks.
 """
 import copy
-import mlt
+import mlt7 as mlt
 import os
 import xml.dom.minidom
 
